%==========================================================================
% [plt_sync_order.m] Generates Figure 2.8
%   Plot peak-mu trend for different inversion filters in SB/HB-IDI
%
%   Author: T.S.C. Pollack
%   Copyright (2024) T.S.C. Pollack
%==========================================================================

clear all; close all; clc;

% Add function path
addpath(pwd);

% Go to path
cd('../../../_FIGDATA/3_INVSTR_TRENDS'); main_path = cd;

%% Collect data

mu_pk_lst_sb = [];
mu_pk_lst_hb = [];
wn_lst_sb    = [];
wn_lst_hb    = [];

% Get directory list
dir_lst = dir;
dir_lst = {dir_lst.name};

for fldr = dir_lst
    
    cd(cell2mat(fldr));
    
    if isfile('umbrella.mat')
       
        load('umbrella.mat');
        
        mu_pk_lst = [umbrella.results.mu_bar_rp(2), umbrella.results.mu_bar_rs(2), ...
            umbrella.results.mu_bar_np(2)];
        
        if strcmp(umbrella.settings.t_indi,'sb')
            
            mu_pk_lst_sb = [mu_pk_lst_sb,mu_pk_lst'];
            
            [wn,~] = damp(umbrella.settings.inv.H_aa_sb);
            wn_lst_sb = [wn_lst_sb,wn(1)];
            
        elseif strcmp(umbrella.settings.t_indi,'hb')
            
            mu_pk_lst_hb = [mu_pk_lst_hb,mu_pk_lst'];
            
            [wn,~] = damp(umbrella.settings.inv.Kh);
            wn_lst_hb = [wn_lst_hb,wn(1)];
            
        end
        
    end
    
    clear umbrella;
    cd(main_path);    
    
end

% Sort results
[wn_lst_sb,I] = sort(wn_lst_sb);
mu_pk_lst_sb  = mu_pk_lst_sb(:,I);
[wn_lst_hb,I] = sort(wn_lst_hb);
mu_pk_lst_hb  = mu_pk_lst_hb(:,I);

% Add optimal mu*SB
cd('../1_MAIN_RESULTS/DATA_BS2_BD_SS01AAE_77ARA_6D')
       
load('umbrella.mat');

mu_pk_opt = umbrella.syn_info(2).PeakMu;
wn_opt = umbrella.syn_info(2).K.K.Value;

cd(main_path);

%% Plot
close all; 

FIG_muBatch = figure; FIG_muBatch.Position = [681 559 560 380];

clr_lst = [[0, 0.4470, 0.7410];[0.8500, 0.3250, 0.0980];[0.4660, 0.6740, 0.1880]; ...
    [0.4940, 0.1840, 0.5560];  [0.6350, 0.0780, 0.1840];[0.25, 0.25, 0.25]; ...
    [0.75, 0.75, 0];[0, 0.75, 0.75];[0.9290, 0.6940, 0.1250]];

% Plot peak mu RP trend
plot(wn_lst_sb,mu_pk_lst_sb(1,:),'k-x',wn_lst_hb,mu_pk_lst_hb(1,:),'k-d')

grid on; hold on;

% Plot peak mu RS & NP trends
plot(wn_lst_sb,mu_pk_lst_sb(2,:),'-x',wn_lst_hb,mu_pk_lst_hb(2,:),'-d', ...
    'color',clr_lst(1,:))
plot(wn_lst_sb,mu_pk_lst_sb(3,:),'-x',wn_lst_hb,mu_pk_lst_hb(3,:),'-d', ...
    'color',clr_lst(end,:))

% Add optimal mu*SB
plot(wn_opt,mu_pk_opt,'ko','MarkerFaceColor','r');

% Set horizontal axis bounds
xlim([wn_lst_sb(1),20]);

% Add legend
hlegend = legend('$\bar{\mu}^{+}_{RP,SB}$','$\bar{\mu}^+_{RP,HB}$', ...
                 '$\bar{\mu}^+_{RS,SB}$','$\bar{\mu}^+_{RS,HB}$', ...
                 '$\bar{\mu}^+_{NP,SB}$','$\bar{\mu}^+_{NP,HB}$', ...
                 '$\bar{\mu}^{*}_{RP,SB}$',... 
                 'Interpreter','latex','Location','NorthEast','FontSize',12);
             
 hlegend.NumColumns  = 2;
 hlegend.Orientation = 'horizontal';

% Add axis labels
xlabel('Break frequency (rad/s)','Interpreter','latex','FontSize',12); 
ylabel('$\bar{\mu}^+$ (-)','Interpreter','latex','FontSize',12); 

set(gca,'TickLabelInterpreter','latex')

% Save file  
saveas(FIG_muBatch,'FIG_muBatch.fig');
saveas(FIG_muBatch,'FIG_muBatch.png');
saveas(FIG_muBatch,'FIG_muBatch.emf');
saveas(FIG_muBatch,'FIG_muBatch','epsc');
