%==========================================================================
% [plt_sync_order.m] Generates Figure 2.6b
%   Plot comparison of different SB-IDI inversion filters 
%
%   Author: T.S.C. Pollack
%   Copyright (2024) T.S.C. Pollack
%==========================================================================

clear all; close all; clc;

% Add function path
addpath(pwd);

% Go to data path
cd('../../../_FIGDATA/2_SYNC_ORDER'); main_path = cd;

%% Collect data

% Get directory list
dir_lst = dir;
dir_lst = {dir_lst.name};

for fldr = dir_lst
    
    cd(cell2mat(fldr));
    
    if isfile('umbrella.mat')
       
        load('umbrella.mat');
        
        if umbrella.settings.syn.fix_form
            umbrella_lp = umbrella;
        else
            umbrella_ll = umbrella;
        end
        
    end
    
    clear umbrella;
    cd(main_path);    
    
end

%% Plot results in bar chart

close all;

% Set frequency range
omega = logspace(-2,3,71);

FIG_CLAWcomp = figure; FIG_CLAWcomp.Position = [681 559 560 380];

[mag_ll,phase_ll,~] = bode(umbrella_ll.systems.K,omega); 
phase_ll = phase_wrapper(phase_ll(:));

[mag_lp,phase_lp,wout] = bode(umbrella_lp.systems.K,omega); 
phase_lp = phase_wrapper(phase_lp(:));

sp1 = subplot(2,1,1);
semilogx(omega,mag2db(mag_ll(:)),'k-'); grid on; hold on;
semilogx(omega,mag2db(mag_lp(:)),'k--');
ylabel('Magnitude (dB)','Interpreter','latex','FontSize',12);
set(gca,'TickLabelInterpreter','latex')
set(gca,'XTickLabel',[])

ylim([-20,0]);

sp1.Position = sp1.Position + [0 -0.05 0 0.05];

% Add legend
legend('Lag-lead', 'Low-pass', ...
    'Interpreter','latex','Location','Best','FontSize',12);

sp2 = subplot(2,1,2);
semilogx(omega,phase_ll,'k-'); grid on; hold on;
semilogx(omega,phase_lp,'k--');
xlabel('Frequency (rad/s)','Interpreter','latex','FontSize',12);
ylabel('Phase (deg)','Interpreter','latex','FontSize',12);
set(gca,'TickLabelInterpreter','latex')

sp2.Position = sp2.Position + [0 0 0 0.05];

% Save file  
saveas(FIG_CLAWcomp,'FIG_CLAWcomp.fig');
saveas(FIG_CLAWcomp,'FIG_CLAWcomp.png');
saveas(FIG_CLAWcomp,'FIG_CLAWcomp.emf');
saveas(FIG_CLAWcomp,'FIG_CLAWcomp','epsc');