%==========================================================================
% [plt_sync_type.m] Generates Figure 2.9
%   Plot peak-mu comparison for different synchronization types in SB-IDI
%
%   Author: T.S.C. Pollack
%   Copyright (2024) T.S.C. Pollack
%==========================================================================

clear all; close all; clc;

% Add function path
addpath(pwd);

% Go to path
cd('../../../_FIGDATA/4_SYNC_TYPE'); main_path = cd;

%% Collect data

mu_pk_lst = [];
settings_lst = {};

% Get directory list
dir_lst = dir;
dir_lst = {dir_lst.name};

for fldr = dir_lst
    
    cd(cell2mat(fldr));
    
    if isfile('umbrella.mat')
       
        load('umbrella.mat');
        
        mu_pk_lst = [mu_pk_lst,[umbrella.results.mu_bar_rp(2), umbrella.results.mu_bar_rs(2), ...
            umbrella.results.mu_bar_np(2)]'];
        
        settings_lst{end+1} = {umbrella.settings.t_actfb,umbrella.settings.t_actfb_mdl, ...
            umbrella.settings.claw_syn,umbrella.settings.syn.fix_form};
        
    end
    
    clear umbrella;
    cd(main_path);    
    
end

%% Sort results

mu_pk_lst = [mu_pk_lst(:,6),mu_pk_lst(:,3),zeros(3,1),mu_pk_lst(:,7), ...
    mu_pk_lst(:,4),mu_pk_lst(:,1),mu_pk_lst(:,8),mu_pk_lst(:,5),mu_pk_lst(:,2)];

mu_rp_pk_lst = reshape(mu_pk_lst(1,:),[3,3])';
mu_rs_pk_lst = reshape(mu_pk_lst(2,:),[3,3])';
mu_np_pk_lst = reshape(mu_pk_lst(3,:),[3,3])';

%% Plot results in bar chart

close all;

FIG_muACT = figure; FIG_muACT.Position = [681 559 560 380];

clr_lst = [[0, 0.4470, 0.7410];[0.8500, 0.3250, 0.0980];[0.4660, 0.6740, 0.1880]; ...
    [0.4940, 0.1840, 0.5560];  [0.6350, 0.0780, 0.1840];[0.25, 0.25, 0.25]; ...
    [0.75, 0.75, 0];[0, 0.75, 0.75];[0.9290, 0.6940, 0.1250]];

b_rp = bar(mu_rp_pk_lst,'FaceColor','k');
grid on
hold on

b_rs = bar(mu_rs_pk_lst,'FaceColor',clr_lst(1,:));
b_np = bar(mu_np_pk_lst,'FaceColor',clr_lst(end,:));

b_rp(1).FaceColor = ones(1,3)*0;
b_rp(2).FaceColor = ones(1,3)*0.5;
b_rp(3).FaceColor = ones(1,3)*0.8;

b_rs(1).FaceColor = clr_lst(1,:);
b_rs(2).FaceColor = [0.2627    0.7020    1.0000];
b_rs(3).FaceColor = [0.7020    0.8784    0.9333];

b_np(1).FaceColor = clr_lst(end,:);
b_np(2).FaceColor = [0.9608    0.8314    0.5137];
b_np(3).FaceColor = [0.9843    0.9294    0.7882];

% Add legend
hlegend = legend('$\bar{\mu}^{*}_{RP,AS}$','$\bar{\mu}^*_{RP,AM}$','$\bar{\mu}^*_{RP,CC}$', ...
                 '$\bar{\mu}^*_{RS,AS}$','$\bar{\mu}^*_{RS,AM}$','$\bar{\mu}^*_{RS,CC}$', ...
                 '$\bar{\mu}^*_{NP,AS}$','$\bar{\mu}^*_{NP,AM}$', '$\bar{\mu}^{*}_{NP,CC}$',... 
                 'Interpreter','latex','Location','best','FontSize',12);
             
hlegend.NumColumns  = 3;
hlegend.Orientation = 'horizontal';
 
ylabel('$\bar{\mu}^*$ (-)','Interpreter','latex','FontSize',12); 

set(gca,'TickLabelInterpreter','latex')
set(gca,'XTickLabel',{'Basic';'Lag-lead';'Low-pass'})

yline(1,'k--'); hlegend.String(end) = [];

% Create textbox
annotation(FIG_muACT,'textbox',...
    [0.282142857142857 0.0963684223074661 0.0747356227544829 0.0684210513767444],...
    'String',{'n/a'},...
    'LineStyle','none',...
    'Interpreter','latex')

% Save file  
saveas(FIG_muACT,'FIG_muACT.fig');
saveas(FIG_muACT,'FIG_muACT.png');
saveas(FIG_muACT,'FIG_muACT.emf');
saveas(FIG_muACT,'FIG_muACT','epsc');
